@@ -124,7 +124,7 @@ namespace Tomboy
 				RegisterSessionManagerRestart (
 				        Environment.GetEnvironmentVariable ("TOMBOY_WRAPPER_PATH"),
 				        args,
-				        new string [] { "TOMBOY_PATH=" + note_path  });
+				        new string [] { "TOMBOY_PATH=" + note_path  }); // TODO: Pass along XDG_*?
 				StartTrayIcon ();
 			}
 
@@ -143,10 +143,10 @@ namespace Tomboy
 			        override_path :
 			        Environment.GetEnvironmentVariable ("TOMBOY_PATH");
 			if (note_path == null)
-				note_path = Services.NativeApplication.ConfDir;
+				note_path = Services.NativeApplication.DataDirectory;
 
 			// Tilde expand
-			return note_path.Replace ("~", Environment.GetEnvironmentVariable ("HOME"));
+			return note_path.Replace ("~", Environment.GetEnvironmentVariable ("HOME")); // TODO: Wasted work
 		}
 
 		static void RegisterPanelAppletFactory ()
@@ -307,16 +307,19 @@ namespace Tomboy
 		static void OnShowAboutAction (object sender, EventArgs args)
 		{
 			string [] authors = new string [] {
-				"Alex Graveley <alex@beatniksoftware.com>",
-				"Boyd Timothy <btimothy@gmail.com>",
-				"Chris Scobell <chris@thescobells.com>",
-				"David Trowbridge <trowbrds@gmail.com>",
-				"Ryan Lortie <desrt@desrt.ca>",
-				"Sandy Armstrong <sanfordarmstrong@gmail.com>",
-				"Sebastian Rittau <srittau@jroger.in-berlin.de>",
-				"Kevin Kubasik <kevin@kubasik.net>",
-				"Stefan Schweizer <steve.schweizer@gmail.com>",
-				"Benjamin Podszun <benjamin.podszun@gmail.com>"
+				Catalog.GetString ("Primary Development:"),
+				"\tAlex Graveley <alex@beatniksoftware.com>",
+				"\tBoyd Timothy <btimothy@gmail.com>",
+				"\tSandy Armstrong <sanfordarmstrong@gmail.com>",
+				"",
+				Catalog.GetString ("Contributors:"),
+				"\tBenjamin Podszun <benjamin.podszun@gmail.com>",
+				"\tChris Scobell <chris@thescobells.com>",
+				"\tDavid Trowbridge <trowbrds@gmail.com>",
+				"\tKevin Kubasik <kevin@kubasik.net>",
+				"\tRyan Lortie <desrt@desrt.ca>",
+				"\tSebastian Rittau <srittau@jroger.in-berlin.de>",
+				"\tStefan Schweizer <steve.schweizer@gmail.com>"
 			};
 
 			string [] documenters = new string [] {
@@ -353,8 +356,10 @@ namespace Tomboy
 			about.Documenters = documenters;
 			about.TranslatorCredits = translators;
 			about.IconName = "tomboy";
-			about.Run ();
-			about.Destroy ();
+			about.Response += delegate {
+				about.Destroy ();
+			};
+			about.Present ();
 		}
 
 		static void OpenSearchAll (object sender, EventArgs args)
